@@ -1,6 +1,6 @@
 // This defines the interface to the QsciLexerPython class.
 //
-// Copyright (c) 2011 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
 // This file is part of QScintilla.
 // 
@@ -16,13 +16,8 @@
 // GPL Exception version 1.1, which can be found in the file
 // GPL_EXCEPTION.txt in this package.
 // 
-// Please review the following information to ensure GNU General
-// Public Licensing requirements will be met:
-// http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-// you are unsure which license is appropriate for your use, please
-// review the following information:
-// http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-// or contact the sales department at sales@riverbankcomputing.com.
+// If you are unsure which license is appropriate for your use, please
+// contact the sales department at sales@riverbankcomputing.com.
 // 
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -211,6 +206,19 @@ public:
     //! \sa setIndentationWarning()
     QsciLexerPython::IndentationWarning indentationWarning() const {return indent_warn;}
 
+    //! If \a enabled is true then sub-identifiers defined in keyword set 2
+    //! will be highlighted.  For example, if it is false and "open" is defined
+    //! in keyword set 2 then "foo.open" will not be highlighted.  The default
+    //! is true.
+    //!
+    //! \sa highlightSubidentifiers()
+    void setHighlightSubidentifiers(bool enabled);
+
+    //! Returns true if string literals are allowed to span newline characters.
+    //!
+    //! \sa setHighlightSubidentifiers()
+    bool highlightSubidentifiers() const {return highlight_subids;}
+
     //! If \a allowed is true then string literals are allowed to span newline
     //! characters.  The default is false.
     //!
@@ -299,6 +307,7 @@ private:
     void setV2UnicodeProp();
     void setV3BinaryOctalProp();
     void setV3BytesProp();
+    void setHighlightSubidsProp();
 
     bool fold_comments;
     bool fold_compact;
@@ -308,6 +317,7 @@ private:
     bool v2_unicode;
     bool v3_binary_octal;
     bool v3_bytes;
+    bool highlight_subids;
 
     friend class QsciLexerHTML;
 
